@@ -1,9 +1,6 @@
-extern crate jsonwebtoken as jwt;
-#[macro_use]
-extern crate serde_derive;
-
-use jwt::errors::ErrorKind;
-use jwt::{decode, encode, Header, Validation};
+use jsonwebtoken::errors::ErrorKind;
+use jsonwebtoken::{decode, encode, DecodingKey, EncodingKey, Header, Validation};
+use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Serialize, Deserialize)]
 struct Claims {
@@ -13,16 +10,16 @@ struct Claims {
 }
 
 fn main() {
+    let key = b"secret";
     let my_claims =
         Claims { sub: "b@b.com".to_owned(), company: "ACME".to_owned(), exp: 10000000000 };
-    let key = "secret";
-    let token = match encode(&Header::default(), &my_claims, key.as_ref()) {
+    let token = match encode(&Header::default(), &my_claims, &EncodingKey::from_secret(key)) {
         Ok(t) => t,
         Err(_) => panic!(), // in practice you would return the error
     };
 
     let validation = Validation { sub: Some("b@b.com".to_string()), ..Validation::default() };
-    let token_data = match decode::<Claims>(&token, key.as_ref(), &validation) {
+    let token_data = match decode::<Claims>(&token, &DecodingKey::from_secret(key), &validation) {
         Ok(c) => c,
         Err(err) => match *err.kind() {
             ErrorKind::InvalidToken => panic!("Token is invalid"), // Example on how to handle a specific error
